@@ -61,11 +61,11 @@ def test_decolorized_format(format, message, expected, writer):
 
 @pytest.fixture
 def patch_colorama(monkeypatch):
-    AnsiToWin32_instance = MagicMock()
-    AnsiToWin32_class = MagicMock(return_value=AnsiToWin32_instance)
+    instance = MagicMock()
+    class_ = MagicMock(return_value=instance)
     winapi_test = MagicMock(return_value=True)
     win32 = MagicMock(winapi_test=winapi_test)
-    colorama = MagicMock(AnsiToWin32=AnsiToWin32_class, win32=win32)
+    colorama = MagicMock(AnsiToWin32=class_, win32=win32)
     monkeypatch.setitem(sys.modules, "colorama", colorama)
     monkeypatch.setitem(sys.modules, "colorama.win32", win32)
     yield colorama
@@ -74,12 +74,13 @@ def patch_colorama(monkeypatch):
 @pytest.mark.parametrize("colorize", [True, False, None])
 @pytest.mark.parametrize("tty", [True, False])
 @pytest.mark.parametrize("replace_original", [True, False])
-def test_colorize_stream(patch_colorama, monkeypatch, colorize, tty, replace_original):
+@pytest.mark.skipif(os.name == "nt", reason="Colorama is required on Windows")
+def test_colorize_stream_linux(patch_colorama, monkeypatch, colorize, tty, replace_original):
     stream = Stream(tty)
 
     monkeypatch.delenv("TERM", raising=False)
     monkeypatch.delenv("PYCHARM_HOSTED", raising=False)
-    monkeypatch.setattr(os, "name", "unix")
+
     if replace_original:
         monkeypatch.setattr(sys, "__stdout__", stream)
 
@@ -101,12 +102,13 @@ def test_colorize_stream(patch_colorama, monkeypatch, colorize, tty, replace_ori
 @pytest.mark.parametrize("colorize", [True, False, None])
 @pytest.mark.parametrize("tty", [True, False])
 @pytest.mark.parametrize("replace_original", [True, False])
+@pytest.mark.skipif(os.name != "nt", reason="Only Windows requires Colorama")
 def test_colorize_stream_windows(patch_colorama, monkeypatch, colorize, tty, replace_original):
     stream = Stream(tty)
 
     monkeypatch.delenv("TERM", raising=False)
     monkeypatch.delenv("PYCHARM_HOSTED", raising=False)
-    monkeypatch.setattr(os, "name", "nt")
+
     if replace_original:
         monkeypatch.setattr(sys, "__stdout__", stream)
 
@@ -125,8 +127,7 @@ def test_colorize_stream_windows(patch_colorama, monkeypatch, colorize, tty, rep
 
 
 @pytest.mark.parametrize("colorize", [True, False, None])
-def test_isatty_error(monkeypatch, colorize):
-    monkeypatch.setattr(os, "name", "posix")
+def test_isatty_error(colorize):
     stream = Stream(None)
     logger.add(stream, format="<blue>{message}</blue>", colorize=colorize)
     logger.debug("Message")
@@ -151,25 +152,83 @@ def test_pycharm_ignored(monkeypatch, stream):
     assert not loguru._colorama.should_colorize(stream)
 
 
+def test_jupyter_fixed(monkeypatch):
+    class Shell:
+        pass
+
+    class Out:
+        pass
+
+    stream = MagicMock()
+    stream.__class__ = Out
+    stream.isatty.return_value = False
+    ipython = MagicMock()
+    ipykernel = MagicMock()
+    instance = MagicMock()
+    instance.__class__ = Shell
+    ipython.get_ipython.return_value = instance
+    ipykernel.zmqshell.ZMQInteractiveShell = Shell
+    ipykernel.iostream.OutStream = Out
+
+    monkeypatch.setitem(sys.modules, "IPython", ipython)
+    monkeypatch.setitem(sys.modules, "ipykernel", ipykernel)
+    monkeypatch.setattr(sys, "stdout", stream)
+
+    assert not stream.isatty()
+    assert loguru._colorama.should_colorize(stream)
+
+
+@pytest.mark.parametrize("stream", [None, Stream(False), Stream(None)])
+def test_jupyter_ignored(monkeypatch, stream):
+    class Shell:
+        pass
+
+    class Out:
+        pass
+
+    ipython = MagicMock()
+    ipykernel = MagicMock()
+    instance = MagicMock()
+    instance.__class__ = Shell
+    ipython.get_ipython.return_value = instance
+    ipykernel.zmqshell.ZMQInteractiveShell = Shell
+    ipykernel.iostream.OutStream = Out
+
+    monkeypatch.setitem(sys.modules, "IPython", ipython)
+    monkeypatch.setitem(sys.modules, "ipykernel", ipykernel)
+    monkeypatch.setattr(sys, "stdout", stream)
+
+    assert not loguru._colorama.should_colorize(stream)
+
+
 @pytest.mark.parametrize("stream", [sys.__stdout__, sys.__stderr__])
-def test_mintty_fixed_windows(monkeypatch, stream):
-    monkeypatch.setattr(os, "name", "nt")
-    monkeypatch.setitem(os.environ, "TERM", "xterm")
+def test_github_actions_fixed(monkeypatch, stream):
+    monkeypatch.setitem(os.environ, "CI", "1")
+    monkeypatch.setitem(os.environ, "GITHUB_ACTIONS", "1")
     monkeypatch.setattr(stream, "isatty", lambda: False)
     assert not stream.isatty()
     assert loguru._colorama.should_colorize(stream)
 
 
 @pytest.mark.parametrize("stream", [None, Stream(False), Stream(None)])
-def test_mintty_ignored_windows(monkeypatch, stream):
-    monkeypatch.setattr(os, "name", "nt")
-    monkeypatch.setitem(os.environ, "TERM", "xterm")
+def test_github_actions_ignored(monkeypatch, stream):
+    monkeypatch.setitem(os.environ, "CI", "1")
+    monkeypatch.setitem(os.environ, "GITHUB_ACTIONS", "1")
     assert not loguru._colorama.should_colorize(stream)
 
 
 @pytest.mark.parametrize("stream", [sys.__stdout__, sys.__stderr__])
+@pytest.mark.skipif(os.name != "nt", reason="The fix is applied only on Windows")
+def test_mintty_fixed_windows(monkeypatch, stream):
+    monkeypatch.setitem(os.environ, "TERM", "xterm")
+    monkeypatch.setattr(stream, "isatty", lambda: False)
+    assert not stream.isatty()
+    assert loguru._colorama.should_colorize(stream)
+
+
+@pytest.mark.parametrize("stream", [sys.__stdout__, sys.__stderr__])
+@pytest.mark.skipif(os.name == "nt", reason="The fix will be applied on Windows")
 def test_mintty_not_fixed_linux(monkeypatch, stream):
-    monkeypatch.setattr(os, "name", "posix")
     monkeypatch.setitem(os.environ, "TERM", "xterm")
     monkeypatch.setattr(stream, "isatty", lambda: False)
     assert not stream.isatty()
@@ -177,7 +236,6 @@ def test_mintty_not_fixed_linux(monkeypatch, stream):
 
 
 @pytest.mark.parametrize("stream", [None, Stream(False), Stream(None)])
-def test_mintty_ignored_linux(monkeypatch, stream):
-    monkeypatch.setattr(os, "name", "posix")
+def test_mintty_ignored(monkeypatch, stream):
     monkeypatch.setitem(os.environ, "TERM", "xterm")
     assert not loguru._colorama.should_colorize(stream)
