@@ -1,7 +1,6 @@
 import asyncio
 import logging
 import multiprocessing
-import platform
 import re
 import sys
 import threading
@@ -263,10 +262,10 @@ def test_complete_stream_noop(capsys):
     assert err == "A\nB\nC\nD\n"
 
 
-def test_complete_file_noop(tmpdir):
-    filepath = tmpdir.join("test.log")
+def test_complete_file_noop(tmp_path):
+    filepath = tmp_path / "test.log"
 
-    logger.add(str(filepath), format="{message}", catch=False)
+    logger.add(filepath, format="{message}", catch=False)
     logger.info("A")
 
     async def worker():
@@ -278,7 +277,7 @@ def test_complete_file_noop(tmpdir):
 
     logger.info("D")
 
-    assert filepath.read() == "A\nB\nC\nD\n"
+    assert filepath.read_text() == "A\nB\nC\nD\n"
 
 
 def test_complete_function_noop():
@@ -507,7 +506,7 @@ def test_complete_from_another_loop(capsys, loop_is_none):
 
 def test_complete_from_multiple_threads_loop_is_none(capsys):
     async def worker(i):
-        for j in range(100):
+        for _ in range(100):
             await asyncio.sleep(0)
             logger.info("{:03}", i)
         await logger.complete()
@@ -535,7 +534,7 @@ def test_complete_from_multiple_threads_loop_is_none(capsys):
 
 def test_complete_from_multiple_threads_loop_is_not_none(capsys):
     async def worker(i):
-        for j in range(100):
+        for _ in range(100):
             await asyncio.sleep(0)
             logger.info("{:03}", i)
         await logger.complete()
@@ -590,7 +589,6 @@ class Writer:
         self.output += message
 
 
-@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy bug #3630")
 def test_complete_with_sub_processes(monkeypatch, capsys):
     ctx = multiprocessing.get_context("spawn")
     monkeypatch.setattr(loguru._handler, "multiprocessing", ctx)
