@@ -6,7 +6,6 @@ import types
 
 import pytest
 
-import loguru
 from loguru import logger
 
 
@@ -65,9 +64,9 @@ def test_sink_encoding(writer, encoding):
     assert writer.output.endswith("ZeroDivisionError: division by zero\n")
 
 
-def test_file_sink_ascii_encoding(tmpdir):
-    file = tmpdir.join("test.log")
-    logger.add(str(file), format="", encoding="ascii", errors="backslashreplace", catch=False)
+def test_file_sink_ascii_encoding(tmp_path):
+    file = tmp_path / "test.log"
+    logger.add(file, format="", encoding="ascii", errors="backslashreplace", catch=False)
     a = "天"
 
     try:
@@ -81,9 +80,9 @@ def test_file_sink_ascii_encoding(tmpdir):
     assert result.count("-> '\\u5929'") == 1
 
 
-def test_file_sink_utf8_encoding(tmpdir):
-    file = tmpdir.join("test.log")
-    logger.add(str(file), format="", encoding="utf8", errors="strict", catch=False)
+def test_file_sink_utf8_encoding(tmp_path):
+    file = tmp_path / "test.log"
+    logger.add(file, format="", encoding="utf8", errors="strict", catch=False)
     a = "天"
 
     try:
@@ -429,3 +428,19 @@ def test_default_with_coroutine():
         return 1 / 0
 
     assert asyncio.run(foo()) == 42
+
+
+def test_error_when_decorating_class_without_parentheses():
+    with pytest.raises(TypeError):
+
+        @logger.catch
+        class Foo:
+            pass
+
+
+def test_error_when_decorating_class_with_parentheses():
+    with pytest.raises(TypeError):
+
+        @logger.catch()
+        class Foo:
+            pass
