@@ -82,7 +82,7 @@ def generate(output, outpath):
     os.makedirs(os.path.dirname(outpath), exist_ok=True)
     with open(outpath, "w") as file:
         file.write(output)
-    assert False  # Avoid forgetting to remove "generate()" inadvertently
+    raise AssertionError("The method 'generate()' was called while running tests.")
 
 
 def compare_exception(dirname, filename):
