@@ -102,7 +102,6 @@ class Writer:
         return self._output
 
 
-@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy bug #3630")
 def test_apply_spawn(spawn_context):
     writer = Writer()
 
@@ -156,7 +155,6 @@ def test_apply_inheritance(fork_context):
     assert writer.read() == "#0\n#1\n#2\nDone!\n"
 
 
-@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy bug #3630")
 def test_apply_async_spawn(spawn_context):
     writer = Writer()
 
@@ -213,7 +211,6 @@ def test_apply_async_inheritance(fork_context):
     assert writer.read() == "#0\n#1\n#2\nDone!\n"
 
 
-@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy bug #3630")
 def test_process_spawn(spawn_context):
     writer = Writer()
 
@@ -267,7 +264,6 @@ def test_process_inheritance(fork_context):
     assert writer.read() == "Child\nMain\n"
 
 
-@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy bug #3630")
 def test_remove_in_child_process_spawn(spawn_context):
     writer = Writer()
 
@@ -321,7 +317,6 @@ def test_remove_in_child_process_inheritance(fork_context):
     assert writer.read() == "Child\nMain\n"
 
 
-@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy bug #3630")
 def test_remove_in_main_process_spawn(spawn_context):
     # Actually, this test may fail if sleep time in main process is too small (and no barrier used)
     # In such situation, it seems the child process has not enough time to initialize itself
@@ -381,7 +376,6 @@ def test_remove_in_main_process_inheritance(fork_context):
     assert writer.read() == "Child\nMain\n"
 
 
-@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy bug #3630")
 def test_await_complete_spawn(capsys, spawn_context):
     async def writer(msg):
         print(msg, end="")
@@ -456,13 +450,12 @@ def test_await_complete_inheritance(capsys, fork_context):
     assert err == ""
 
 
-@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy bug #3630")
-def test_not_picklable_sinks_spawn(spawn_context, tmpdir, capsys):
-    filepath = tmpdir.join("test.log")
+def test_not_picklable_sinks_spawn(spawn_context, tmp_path, capsys):
+    filepath = tmp_path / "test.log"
     stream = sys.stderr
     output = []
 
-    logger.add(str(filepath), format="{message}", enqueue=True, catch=False)
+    logger.add(filepath, format="{message}", enqueue=True, catch=False)
     logger.add(stream, format="{message}", enqueue=True)
     logger.add(lambda m: output.append(m), format="{message}", enqueue=True)
 
@@ -477,19 +470,19 @@ def test_not_picklable_sinks_spawn(spawn_context, tmpdir, capsys):
 
     out, err = capsys.readouterr()
 
-    assert filepath.read() == "Child\nMain\n"
+    assert filepath.read_text() == "Child\nMain\n"
     assert out == ""
     assert err == "Child\nMain\n"
     assert output == ["Child\n", "Main\n"]
 
 
 @pytest.mark.skipif(os.name == "nt", reason="Windows does not support forking")
-def test_not_picklable_sinks_fork(capsys, tmpdir, fork_context):
-    filepath = tmpdir.join("test.log")
+def test_not_picklable_sinks_fork(capsys, tmp_path, fork_context):
+    filepath = tmp_path / "test.log"
     stream = sys.stderr
     output = []
 
-    logger.add(str(filepath), format="{message}", enqueue=True, catch=False)
+    logger.add(filepath, format="{message}", enqueue=True, catch=False)
     logger.add(stream, format="{message}", enqueue=True, catch=False)
     logger.add(lambda m: output.append(m), format="{message}", enqueue=True, catch=False)
 
@@ -504,19 +497,19 @@ def test_not_picklable_sinks_fork(capsys, tmpdir, fork_context):
 
     out, err = capsys.readouterr()
 
-    assert filepath.read() == "Child\nMain\n"
+    assert filepath.read_text() == "Child\nMain\n"
     assert out == ""
     assert err == "Child\nMain\n"
     assert output == ["Child\n", "Main\n"]
 
 
 @pytest.mark.skipif(os.name == "nt", reason="Windows does not support forking")
-def test_not_picklable_sinks_inheritance(capsys, tmpdir, fork_context):
-    filepath = tmpdir.join("test.log")
+def test_not_picklable_sinks_inheritance(capsys, tmp_path, fork_context):
+    filepath = tmp_path / "test.log"
     stream = sys.stderr
     output = []
 
-    logger.add(str(filepath), format="{message}", enqueue=True, catch=False)
+    logger.add(filepath, format="{message}", enqueue=True, catch=False)
     logger.add(stream, format="{message}", enqueue=True, catch=False)
     logger.add(lambda m: output.append(m), format="{message}", enqueue=True, catch=False)
 
@@ -531,7 +524,7 @@ def test_not_picklable_sinks_inheritance(capsys, tmpdir, fork_context):
 
     out, err = capsys.readouterr()
 
-    assert filepath.read() == "Child\nMain\n"
+    assert filepath.read_text() == "Child\nMain\n"
     assert out == ""
     assert err == "Child\nMain\n"
     assert output == ["Child\n", "Main\n"]
@@ -541,13 +534,13 @@ def test_not_picklable_sinks_inheritance(capsys, tmpdir, fork_context):
 @pytest.mark.skipif(sys.version_info < (3, 7), reason="No 'os.register_at_fork()' function")
 @pytest.mark.parametrize("enqueue", [True, False])
 @pytest.mark.parametrize("deepcopied", [True, False])
-def test_no_deadlock_if_internal_lock_in_use(tmpdir, enqueue, deepcopied, fork_context):
+def test_no_deadlock_if_internal_lock_in_use(tmp_path, enqueue, deepcopied, fork_context):
     if deepcopied:
         logger_ = copy.deepcopy(logger)
     else:
         logger_ = logger
 
-    output = tmpdir.join("stdout.txt")
+    output = tmp_path / "stdout.txt"
     stdout = output.open("w")
 
     def slow_sink(msg):
@@ -570,13 +563,13 @@ def test_no_deadlock_if_internal_lock_in_use(tmpdir, enqueue, deepcopied, fork_c
     process.start()
 
     thread.join()
-    process.join(1)
+    process.join(2)
 
     assert process.exitcode == 0
 
     logger_.remove()
 
-    assert output.read() in ("Main\nChild\n", "Child\nMain\n")
+    assert output.read_text() in ("Main\nChild\n", "Child\nMain\n")
 
 
 @pytest.mark.skipif(sys.version_info < (3, 7), reason="No 'os.register_at_fork()' function")
