@@ -1,8 +1,11 @@
 import logging
-import pytest
 import sys
-from loguru import logger
 from logging import StreamHandler
+
+import pytest
+
+from loguru import logger
+
 from .conftest import make_logging_logger
 
 
@@ -12,8 +15,15 @@ class PropagateHandler(logging.Handler):
 
 
 def test_formatting(capsys):
-    fmt = "%(name)s - %(filename)s - %(funcName)s - %(levelname)s - %(levelno)s - %(lineno)d - %(module)s - %(message)s"
-    expected = "tests.test_propagation - test_propagation.py - test_formatting - DEBUG - 10 - 20 - test_propagation - This is my message\n"
+    fmt = (
+        "%(name)s - %(filename)s - %(funcName)s - %(levelname)s - "
+        "%(levelno)s - %(lineno)d - %(module)s - %(message)s"
+    )
+
+    expected = (
+        "tests.test_propagation - test_propagation.py - test_formatting - DEBUG - "
+        "10 - 30 - test_propagation - This is my message\n"
+    )
 
     with make_logging_logger("tests.test_propagation", StreamHandler(sys.stderr), fmt):
         logger.add(PropagateHandler(), format="{message}")
@@ -76,7 +86,7 @@ def test_exception(capsys, use_opt):
 
         try:
             1 / 0
-        except:
+        except Exception:
             if use_opt:
                 logger.opt(exception=True).error("Oops...")
             else:
