@@ -1,7 +1,8 @@
-from threading import Thread, Barrier
 import itertools
-from loguru import logger
 import time
+from threading import Barrier, Thread
+
+from loguru import logger
 
 
 class NonSafeSink:
@@ -113,8 +114,8 @@ def test_safe_removing_while_logging(capsys):
 def test_safe_writing_after_removing(capsys):
     barrier = Barrier(2)
 
+    logger.add(NonSafeSink(1), format="{message}", catch=False)
     i = logger.add(NonSafeSink(1), format="{message}", catch=False)
-    j = logger.add(NonSafeSink(1), format="{message}", catch=False)
 
     def write():
         barrier.wait()
@@ -123,7 +124,7 @@ def test_safe_writing_after_removing(capsys):
     def remove():
         barrier.wait()
         time.sleep(0.5)
-        logger.remove(j)
+        logger.remove(i)
 
     threads = [Thread(target=write), Thread(target=remove)]
 
